<TS language="it_IT" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Click destro per modificare indirizzo o etichetta</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Crea un nuovo indirizzo </translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copia l'indirizzo selezionato nella clipboard di sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Chiudi </translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Cancella l'indirizzo attualmente selezionato dalla lista.</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Inserire indirizzo o etichetta da cercare</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Esportare i dati nella scheda corrente in un file</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Scegli l'indirizzo a cui inviare denaro</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Scegli l'indirizzo dove accreditare i coins</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Scegli</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Indirizzi mandanti</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Indirizzi riceventi</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Questi sono i suoi indirizzi Litecoin per ricevere i pagamenti. Controlla sempre l'importo e gli indirizzi prima di inviare i coins.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Questi sono i tuoi indirizzi Litecoin per ricevere i pagamenti. Si raccomanda di usare un nuovo indirizzo per ogni transazione.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>copia indirizzo </translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>copia etichetta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Esporta lista indirizzi</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma separated file (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Esportazione Fallita</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Finestra Password</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Inserisci la password</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nuova password</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ripeti nuova password</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>mostra password</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Inserisci la nuova password per il portafoglio.&lt;br/&gt;Per favore usa una password di &lt;b&gt;dieci o più caratteri casuali&lt;/b&gt;, oppure &lt;b&gt;otto o più parole&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cripta portafoglio</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Questa operazione necessita della password del tuo portafoglio per sbloccare il portafoglio.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Sblocca portafoglio</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Questa operazione necessita della password del tuo portafoglio per decriptare il portafoglio.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Decripta portafoglio</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambia password</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Inserisci la vecchia password e la nuova password per decriptare il portafoglio.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Conferma criptaggio portafoglio</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Attenzione: Se cripti il tuo portafoglio e perdi la password, &lt;b&gt;PERDERAI TUTTI I TUOI LITECOIN&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Sei sicuro di voler criptare il tuo portafoglio?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portafoglio criptato</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANTE: Qualsiasi backup precedentemente effettuato del tuo portafoglio dovrebbe essere sostituito con il nuovo file criptato generato. Per questioni di sicurezza, backup precedenti del portafoglio non criptati diverranno inutili non appena inizi ad usare il nuovo portafoglio criptato.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Criptaggio del portafoglio fallito</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Criptaggio del portafoglio fallito per un errore interno. Il tuo portafoglio non è stato criptato.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>La password fornite non corrispondono.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Sblocco portafoglio fallito</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La password inserita per decriptare il portafoglio è errata.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Decriptaggio portafoglio fallito</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>La password del portafoglio è stata cambiata correttamente.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Attenzione: Il tasto blocco delle maiuscole è attivo!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Bannato fino </translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Firma &amp;messaggio...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sincronizzazione con la rete...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Panoramica</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostra panoramica generale del portafoglio</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>Transazioni</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Esplora cronologia transazioni</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Termina applicazione</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>Di più su %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Mostra informazioni su %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Di più su Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Mostra informazioni su Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Modifica opzioni di configurazione per %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Cripta portafoglio</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Backup portafoglio</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Cambia Password...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Apri &amp;URI...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Portafoglio</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Clicca per disabilitare attività di rete.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Attività di rete disabilitata.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Clicca per riabilitare attività di rete.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Sincronizzazione Header (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Reindicizzazione dei blocchi sul disco...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Invia monete ad un indirizzo Litecoin...</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Backup del portafoglio in un'altra posizione</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambia la password usata per criptare il portafoglio</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Finestra di debug</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Apri console di debug e diagnosi</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Verifica messaggio...</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>Ricevi</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Mostra / Nascondi</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Mostra o nascondi la finestra principale</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Cripta le chiavi private che appartengono al tuo portafoglio</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Firma messaggi con i tuoi indirizzi Litecoin per provare che li possiedi</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Verifica messaggi per accertarti che siano firmati dagli indirizzi Litecoin specificati</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Richiedi pagamenti (genera codici QR e litecoin: URI)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Mostra la lista degli indirizzi di invio usati e le relative etichette</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Mostra la lista degli indirizzi di ricezione usati e le relative etichette</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Apri un litecoin: URI o una richiesta di pagamento</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>Opzioni linea di comando</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indicizzazione blocchi su disco...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Elaborazione blocchi su disco...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 indietro</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Ultimo blocco ricevuto generato %1 fa.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Le transazioni dopo di questa non saranno più visibili</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informazione</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Aggiornato</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Litecoin command-line options</source>
        <translation>Mostra il %1 messaggio d'aiuto per ottenere una lista con le possibili opzioni per la riga di comando di Litecoin</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation>Portafoglio predefinito</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Data: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Importo: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tipo: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Etichetta: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Indirizzo: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transazione inviata</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transazione in arrivo</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation>Generazione  di chiavi HD &lt;b&gt;abilitata&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation>Generazione di chiavi HD &lt;b&gt;disabilitata&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>Si è verificato un errore fatale. Litecoin non può continuare in maniera sicura e sarà chiuso.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Selezione delle monete</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Quantità:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Importo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tassa:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Minimo:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(de)seleziona tutto</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Modalità albero</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Modalità lista</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Ricevuto con etichetta</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Ricevuto con indirizzo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Conferme</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confermato</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copia indirizzo</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia etichetta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia importo</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia ID transazione</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>Blocca non spese</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>Sblocca non spese</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia quantità</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia tassa</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Copia minimo</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia cambio</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 bloccato)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>si</translation>
    </message>
    <message>
        <source>no</source>
        <translation>no</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Questa etichetta diventa rossa se qualsiasi destinatario riceve un importo inferiore al limite minimo corrente.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(cambio)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Modifica Indirizzo</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etichetta</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>L'etichetta associata con questa voce dell'elenco indirizzi</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>L'indirizzo associato con questa voce dell'elenco indirizzi. Può essere modificato per inviare indirizzi.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Indirizzo</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nuovo indirizzo di invio</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Modifica l'indirizzo di ricezione</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Modifica l'indirizzo di invio</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Litecoin address.</source>
        <translation>L'indirizzo inserito "%1" non è un indirizzo Litecoin valido.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Non posso sbloccare il portafoglio.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Generazione della nuova chiave fallita.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Una nuova cartella dei dati verrà creata.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>nome</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>La cartella esiste già. Aggiungi %1 se vuoi creare una nuova cartella qui.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Il percorso esiste già, e non è una cartella.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Non posso creare la cartella dei dati qui.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versione</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opzioni linea di comando</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Benvenuto</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Il wallet verra' inoltre memorizzato su questa cartella.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the litecoin network, as detailed below.</source>
        <translation>Le transazioni recenti potrebbero non essere ancora visibili, e quindi il saldo del wallet potrebbe essere incorretto. Questa informazione verra' corretta non appena il tuo wallet ha finito di sincronizzarsi con la rete litecoin, come specificato di seguito.</translation>
    </message>
    <message>
        <source>Attempting to spend litecoins that are affected by not-yet-displayed transactions will not be accepted by the network.</source>
        <translation>Tentare di spendere litecoin che sono affetti da transazioni non ancora mostrate, non verra' accettato dal network.</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Numero di blocchi rimanente</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Opzioni di configurazione</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Questa modifica richiede un riavvio del client</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Available:</source>
        <translation>Disponibile:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Saldo disponibile</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totale:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Bilancio totale attuale</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>Spendibile:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Transazioni recenti</translation>
    </message>
    <message>
        <source>Current total balance in watch-only addresses</source>
        <translation>Bilancio totale attuale su indirizzi watch-only</translation>
    </message>
</context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>URI handling</source>
        <translation>Gestione URI</translation>
    </message>
    <message>
        <source>'litecoin://' is not a valid URI. Use 'litecoin:' instead.</source>
        <translation>'litecoin://' non è un URI valido. Usa invece 'litecoin:'.</translation>
    </message>
    <message>
        <source>Invalid payment address %1</source>
        <translation>Indirizzo di pagamento non valido %1</translation>
    </message>
    <message>
        <source>Payment request rejected</source>
        <translation>Richiesta di pagamento rifiutata</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Richiesta di pagamento scaduta.</translation>
    </message>
    <message>
        <source>Invalid payment request.</source>
        <translation>Richiesta di pagamento non valida.</translation>
    </message>
    <message>
        <source>Refund from %1</source>
        <translation>Rimborso da %1</translation>
    </message>
    <message>
        <source>Error communicating with %1: %2</source>
        <translation>Errore nella comunicazione con %1: %2</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Sent</source>
        <translation>Inviato</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Sent</source>
        <translation>Inviato</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy label</source>
        <translation>Copia etichetta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia importo</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portafoglio</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Quantità:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Importo:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tassa:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Minimo:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copia quantità</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia importo</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copia tassa</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copia bytes</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Copia minimo</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copia cambio</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Richiesta di pagamento scaduta.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Importo</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nessuna etichetta)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy address</source>
        <translation>Copia indirizzo</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copia etichetta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copia importo</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copia ID transazione</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma separated file (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confermato</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Indirizzo</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Esportazione Fallita</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>Portafoglio predefinito</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Information</source>
        <translation>Informazione</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
</TS>